thread_rank
产品支持情况
- Ascend 950PR/Ascend 950DT:支持
- Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
- Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
- Atlas 200I/500 A2 推理产品:不支持
- Atlas 推理系列产品AI Core:不支持
- Atlas 推理系列产品Vector Core:不支持
- Atlas 训练系列产品:不支持
功能说明
获取当前线程在coalesced_group组内的排名,排名从0开始。
函数原型
C++
unsigned long long thread_rank() const
参数说明
无
返回值说明
当前线程在coalesced_group组内的排名。
约束说明
无
调用示例
示例代码中的条件分支将一个warp中所有线程id是偶数的线程组成coalesced_group协作组,组内各线程thread_rank接口返回结果如下图所示。
图1 coalesced_group组内各线程rank
SIMT编程场景:
C++using namespace cooperative_groups; __global__ void simt_kernel(...) { ... if (threadIdx.x % 2 == 0) { coalesced_group active = coalesced_threads(); unsigned long long rank = active.thread_rank(); } ... }SIMD与SIMT混合编程场景:
C++using namespace cooperative_groups; __simt_vf__ inline void simt_kernel(...) { ... if (threadIdx.x % 2 == 0) { coalesced_group active = coalesced_threads(); unsigned long long rank = active.thread_rank(); } ... }